==> onos-yang-runtime-2.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/TeTemplateName.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology;

import java.util.Objects;

/**
 * Represents the implementation of teTemplateName.
 */
public final class TeTemplateName {

    private String string;

    /**
     * Creates an instance of teTemplateName.
     */
    private TeTemplateName() {
    }

    /**
     * Creates an instance of string.
     *
     * @param string value of string
     */
    public TeTemplateName(String string) {
        this.string = string;
    }

    /**
     * Returns the object of teTemplateName for type string.
     *
     * @param value value of teTemplateName for type string
     * @return teTemplateName for type string
     */
    public static TeTemplateName of(String value) {
        return new TeTemplateName(value);
    }

    /**
     * Returns the attribute string.
     *
     * @return string value of string
     */
    public String string() {
        return string;
    }
    /**
     * Sets the attribute string.
     *
     * @param string value of string
     */
    public void string(String string) {
        this.string = string;
    }

    @Override
    public int hashCode() {
        return Objects.hash(string);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof TeTemplateName) {
            TeTemplateName other = (TeTemplateName) obj;
            return
                Objects.equals(string, other.string);
        }
        return false;
    }

    @Override
    public String toString() {
        return string;
    }
    /**
     * Returns the object of teTemplateName fromString input String teTemplateName.
     *
     * @param valInString value of input String
     * @return teTemplateName
     */
    public static TeTemplateName fromString(String valInString) {
        try {
            String tmpVal = (valInString);
            return of(tmpVal);
        } catch (Exception e) {
            throw new IllegalArgumentException("not a valid input element");
        }
    }
}

==> onos-yang-runtime-2.4-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/TeTemplateName.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology;

import java.util.Objects;

/**
 * Represents the implementation of teTemplateName.
 */
public final class TeTemplateName {

    private String string;

    /**
     * Creates an instance of teTemplateName.
     */
    private TeTemplateName() {
    }

    /**
     * Creates an instance of string.
     *
     * @param string value of string
     */
    public TeTemplateName(String string) {
        this.string = string;
    }

    /**
     * Returns the object of teTemplateName for type string.
     *
     * @param value value of teTemplateName for type string
     * @return teTemplateName for type string
     */
    public static TeTemplateName of(String value) {
        return new TeTemplateName(value);
    }

    /**
     * Returns the attribute string.
     *
     * @return string value of string
     */
    public String string() {
        return string;
    }
    /**
     * Sets the attribute string.
     *
     * @param string value of string
     */
    public void string(String string) {
        this.string = string;
    }

    @Override
    public int hashCode() {
        return Objects.hash(string);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof TeTemplateName) {
            TeTemplateName other = (TeTemplateName) obj;
            return
                Objects.deepEquals(string, other.string);
        }
        return false;
    }

    @Override
    public String toString() {
        return string;
    }
    /**
     * Returns the object of teTemplateName fromString input String teTemplateName.
     *
     * @param valInString value of input String
     * @return teTemplateName
     */
    public static TeTemplateName fromString(String valInString) {
        try {
            String tmpVal = (valInString);
            return of(tmpVal);
        } catch (Exception e) {
            throw new IllegalArgumentException("not a valid input element");
        }
    }
}
